pub enum SubstrateStateMachineError {
ProofDecodeError(Error),
MissingChildTrieRoot,
TrieError(String),
MissingMembershipValue(Vec<u8>),
DeliveredRequestsInBatch,
}Expand description
Errors produced by the substrate state machine client.
Variants
ProofDecodeError(Error)
Failed to SCALE-decode the supplied proof.
MissingChildTrieRoot
The state commitment doesn’t include the child trie root, and the request state machine is not the coprocessor.
TrieError(String)
The trie backend returned an error while reading a key.
MissingMembershipValue(Vec<u8>)
A membership proof omitted the value for one of the requested keys.
DeliveredRequestsInBatch
A non-membership proof contained at least one delivered request.